@@ -68,7 +68,7 @@ from typing import Any, Dict, List, Optional, Union
 from ae.core import stack_variables, try_eval  # type: ignore
 
 
-__version__ = '0.0.3'
+__version__ = '0.0.6'
 
 
 MsgType = Union[str, Dict[str, str]]                    #: type of message translations within :data:`MSG_FILE_SUFFIX`
@@ -76,12 +76,14 @@ LanguageMessages = Dict[str, MsgType]                   #: type of the data stru
 
 
 MSG_FILE_SUFFIX = 'Msg.txt'                             #: file name containing translated texts of a language/locale
+DEF_LANGUAGE = 'en_US'                                  #: language code of the messages in your app code
+DEF_ENCODING = 'UTF-8'                                  #: encoding of the messages in your app code
 
 _LANG, _ENC = locale.getdefaultlocale()
 if not _LANG:
-    _LANG = 'en_US'     # pragma: no cover
+    _LANG = DEF_LANGUAGE     # pragma: no cover
 if not _ENC:
-    _ENC = 'UTF-8'      # pragma: no cover
+    _ENC = DEF_ENCODING      # pragma: no cover
 default_locale: List[str] = [_LANG, _ENC]               #: language and encoding code of the current language/locale
 del _LANG, _ENC
 
@@ -99,6 +101,8 @@ def default_language(new_lang: str = '') -> str:
     old_lang = default_locale[0]
     if new_lang:
         default_locale[0] = new_lang
+        if new_lang in installed_languages and new_lang not in loaded_languages:
+            load_language_texts(new_lang)
     return old_lang
 
 
@@ -193,7 +197,7 @@ _ = get_text         #: alias of :func:`get_text`.
 def get_f_string(f_string: str, count: Optional[int] = None, language: str = '',
                  glo_vars: Optional[Dict[str, Any]] = None, loc_vars: Optional[Dict[str, Any]] = None
                  ) -> str:
-    """ translate passed f-string into a f-string of the current language.
+    """ translate passed f-string into a message string of the passed / default language.
 
     :param f_string:    f-string to be translated and evaluated.
     :param count:       pass if the translated text changes on pluralization (see :func:`get_text`).
@@ -216,7 +220,9 @@ def get_f_string(f_string: str, count: Optional[int] = None, language: str = '',
         assert isinstance(glo_vars, dict)       # mypy
         glo_vars['count'] = count
 
-    return try_eval('f"' + f_string + '"', ignored_exceptions=(Exception, ), glo_vars=glo_vars, loc_vars=loc_vars) \
+    return (
+        '{' in f_string and '}' in f_string
+        and try_eval('f"' + f_string + '"', ignored_exceptions=(Exception, ), glo_vars=glo_vars, loc_vars=loc_vars)) \
         or f_string
 
 
@@ -249,13 +255,12 @@ def init_installed_languages():
 
     for path in locale_paths:
         if os.path.exists(path):
-            installed_languages.extend(dir_entry.name for dir_entry in os.scandir(path)
-                                       if dir_entry.is_dir() and dir_entry.name != '__pycache__')
+            installed_languages.extend(
+                dir_entry.name for dir_entry in os.scandir(path)
+                if dir_entry.is_dir() and os.path.exists(os.path.join(dir_entry.path, MSG_FILE_SUFFIX)))
 
 
 # load and set the system/os locale/language/encoding as the app defaults at startup (import)
 init_installed_languages()
 if default_locale[0] in installed_languages:  # pragma: no cover
     load_language_texts(default_locale[0], encoding=default_locale[1])
-    default_language(default_locale[0])
-    default_encoding(default_locale[1])
